/* searchbar.c generated by valac 0.22.1.2-49127, the Vala compiler
 * generated from searchbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <libgd/gd.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;
typedef struct _BoxesSearchbarPrivate BoxesSearchbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _Block53Data Block53Data;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesSearchbar {
	BoxesUI parent_instance;
	BoxesSearchbarPrivate * priv;
};

struct _BoxesSearchbarClass {
	BoxesUIClass parent_class;
};

struct _BoxesSearchbarPrivate {
	GtkClutterActor* gtk_actor;
	GdTaggedEntry* entry;
	guint refilter_delay_id;
	gulong key_handler_id;
	gboolean _visible;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _Block53Data {
	int _ref_count_;
	BoxesSearchbar * self;
	gboolean preedit_changed;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;


static gpointer boxes_searchbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
#define BOXES_SEARCHBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SEARCHBAR, BoxesSearchbarPrivate))
enum  {
	BOXES_SEARCHBAR_DUMMY_PROPERTY,
	BOXES_SEARCHBAR_ACTOR,
	BOXES_SEARCHBAR_ENABLE_KEY_HANDLER,
	BOXES_SEARCHBAR_VISIBLE,
	BOXES_SEARCHBAR_TEXT
};
#define BOXES_SEARCHBAR_refilter_delay ((guint) 200)
BoxesSearchbar* boxes_searchbar_new (void);
BoxesSearchbar* boxes_searchbar_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
static void boxes_searchbar_setup_searchbar (BoxesSearchbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static gboolean boxes_searchbar_on_app_key_pressed (BoxesSearchbar* self, GtkWidget* widget, GdkEventKey* event);
static gboolean _boxes_searchbar_on_app_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static void __lambda33_ (BoxesSearchbar* self);
const gchar* boxes_searchbar_get_text (BoxesSearchbar* self);
static gboolean boxes_searchbar_refilter (BoxesSearchbar* self);
static gboolean _boxes_searchbar_refilter_gsource_func (gpointer self);
static void ___lambda33__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda145_ (BoxesSearchbar* self);
void boxes_collection_view_activate (BoxesCollectionView* self);
static void ___lambda145__gtk_entry_activate (GtkEntry* _sender, gpointer self);
void boxes_collection_filter_set_text (BoxesCollectionFilter* self, const gchar* value);
void boxes_collection_view_refilter (BoxesCollectionView* self);
void boxes_searchbar_grab_focus (BoxesSearchbar* self);
static Block53Data* block53_data_ref (Block53Data* _data53_);
static void block53_data_unref (void * _userdata_);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void __lambda30_ (Block53Data* _data53_);
static void ___lambda30__gtk_entry_preedit_changed (GtkEntry* _sender, const gchar* p0, gpointer self);
gboolean boxes_searchbar_get_visible (BoxesSearchbar* self);
void boxes_searchbar_set_text (BoxesSearchbar* self, const gchar* value);
void boxes_searchbar_set_visible (BoxesSearchbar* self, gboolean value);
static void boxes_searchbar_real_ui_state_changed (BoxesUI* base);
void boxes_searchbar_set_enable_key_handler (BoxesSearchbar* self, gboolean value);
void boxes_revealer_set_revealed (BoxesRevealer* self, gboolean value);
static void boxes_searchbar_finalize (GObject* obj);
static void _vala_boxes_searchbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_searchbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static gboolean _boxes_searchbar_on_app_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = boxes_searchbar_on_app_key_pressed (self, _sender, event);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 344 "searchbar.c"
}


static gboolean _boxes_searchbar_refilter_gsource_func (gpointer self) {
	gboolean result;
	result = boxes_searchbar_refilter (self);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 353 "searchbar.c"
}


static void __lambda33_ (BoxesSearchbar* self) {
	guint _tmp0_ = 0U;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->refilter_delay_id;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 365 "searchbar.c"
		guint _tmp1_ = 0U;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp1_ = self->priv->refilter_delay_id;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_source_remove (_tmp1_);
#line 371 "searchbar.c"
	}
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = boxes_searchbar_get_text (self);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = _tmp2_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (g_strcmp0 (_tmp3_, "") == 0) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_refilter (self);
#line 381 "searchbar.c"
	} else {
		guint _tmp4_ = 0U;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp4_ = g_timeout_add_full (G_PRIORITY_DEFAULT, BOXES_SEARCHBAR_refilter_delay, _boxes_searchbar_refilter_gsource_func, g_object_ref (self), g_object_unref);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		self->priv->refilter_delay_id = _tmp4_;
#line 388 "searchbar.c"
	}
}


static void ___lambda33__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	__lambda33_ (self);
#line 396 "searchbar.c"
}


static void __lambda145_ (BoxesSearchbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = boxes_app_app;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _tmp0_->view;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_collection_view_activate (_tmp1_);
#line 409 "searchbar.c"
}


static void ___lambda145__gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	__lambda145_ (self);
#line 416 "searchbar.c"
}


BoxesSearchbar* boxes_searchbar_construct (GType object_type) {
	BoxesSearchbar * self = NULL;
	BoxesApp* _tmp0_ = NULL;
	GtkApplicationWindow* _tmp1_ = NULL;
	gulong _tmp2_ = 0UL;
	GdTaggedEntry* _tmp3_ = NULL;
	GdTaggedEntry* _tmp4_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = (BoxesSearchbar*) boxes_ui_construct (object_type);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_searchbar_setup_searchbar (self);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = boxes_app_app;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _tmp0_->window;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = g_signal_connect_object ((GtkWidget*) _tmp1_, "key-press-event", (GCallback) _boxes_searchbar_on_app_key_pressed_gtk_widget_key_press_event, self, 0);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->key_handler_id = _tmp2_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = self->priv->entry;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::text", (GCallback) ___lambda33__g_object_notify, self, 0);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp4_ = self->priv->entry;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_signal_connect_object ((GtkEntry*) _tmp4_, "activate", (GCallback) ___lambda145__gtk_entry_activate, self, 0);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return self;
#line 449 "searchbar.c"
}


BoxesSearchbar* boxes_searchbar_new (void) {
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return boxes_searchbar_construct (BOXES_TYPE_SEARCHBAR);
#line 456 "searchbar.c"
}


static gboolean boxes_searchbar_refilter (BoxesSearchbar* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_ = NULL;
	BoxesCollectionFilter* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	BoxesApp* _tmp4_ = NULL;
	BoxesCollectionView* _tmp5_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = boxes_app_app;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _tmp0_->filter;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = boxes_searchbar_get_text (self);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = _tmp2_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_collection_filter_set_text (_tmp1_, _tmp3_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp4_ = boxes_app_app;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp5_ = _tmp4_->view;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_collection_view_refilter (_tmp5_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->refilter_delay_id = (guint) 0;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = FALSE;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 492 "searchbar.c"
}


void boxes_searchbar_grab_focus (BoxesSearchbar* self) {
	GdTaggedEntry* _tmp0_ = NULL;
	GdkDevice* _tmp1_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->entry;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = gtk_get_current_event_device ();
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gd_entry_focus_hack ((GtkWidget*) _tmp0_, _tmp1_);
#line 507 "searchbar.c"
}


static Block53Data* block53_data_ref (Block53Data* _data53_) {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_atomic_int_inc (&_data53_->_ref_count_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return _data53_;
#line 516 "searchbar.c"
}


static void block53_data_unref (void * _userdata_) {
	Block53Data* _data53_;
	_data53_ = (Block53Data*) _userdata_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (g_atomic_int_dec_and_test (&_data53_->_ref_count_)) {
#line 525 "searchbar.c"
		BoxesSearchbar * self;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		self = _data53_->self;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_g_object_unref0 (self);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_slice_free (Block53Data, _data53_);
#line 533 "searchbar.c"
	}
}


static void __lambda30_ (Block53Data* _data53_) {
	BoxesSearchbar * self;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = _data53_->self;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data53_->preedit_changed = TRUE;
#line 544 "searchbar.c"
}


static void ___lambda30__gtk_entry_preedit_changed (GtkEntry* _sender, const gchar* p0, gpointer self) {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	__lambda30_ (self);
#line 551 "searchbar.c"
}


static gboolean boxes_searchbar_on_app_key_pressed (BoxesSearchbar* self, GtkWidget* widget, GdkEventKey* event) {
	gboolean result = FALSE;
	Block53Data* _data53_;
	gboolean handled = FALSE;
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
	GdTaggedEntry* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gulong preedit_changed_id = 0UL;
	GdTaggedEntry* _tmp8_ = NULL;
	gulong _tmp9_ = 0UL;
	gchar* old_text = NULL;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	gboolean _tmp20_ = FALSE;
	gboolean _tmp21_ = FALSE;
	GdTaggedEntry* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
	gboolean _tmp24_ = FALSE;
	gboolean _tmp31_ = FALSE;
	gboolean res = FALSE;
	gboolean _tmp32_ = FALSE;
	gboolean _tmp33_ = FALSE;
	gboolean _tmp34_ = FALSE;
	gboolean _tmp35_ = FALSE;
	gboolean _tmp36_ = FALSE;
	gboolean _tmp37_ = FALSE;
	gboolean _tmp38_ = FALSE;
	gboolean _tmp39_ = FALSE;
	gboolean _tmp40_ = FALSE;
	gboolean _tmp41_ = FALSE;
	gboolean _tmp42_ = FALSE;
	gboolean _tmp43_ = FALSE;
	gboolean _tmp44_ = FALSE;
	gboolean _tmp45_ = FALSE;
	gboolean _tmp46_ = FALSE;
	gboolean _tmp47_ = FALSE;
	gboolean _tmp48_ = FALSE;
	gboolean _tmp49_ = FALSE;
	GdkEventKey _tmp50_ = {0};
	guint _tmp51_ = 0U;
	gboolean _tmp54_ = FALSE;
	gboolean _tmp57_ = FALSE;
	gboolean _tmp60_ = FALSE;
	gboolean _tmp63_ = FALSE;
	gboolean _tmp66_ = FALSE;
	gboolean _tmp69_ = FALSE;
	gboolean _tmp72_ = FALSE;
	gboolean _tmp75_ = FALSE;
	gboolean _tmp78_ = FALSE;
	gboolean _tmp81_ = FALSE;
	gboolean _tmp84_ = FALSE;
	gboolean _tmp87_ = FALSE;
	gboolean _tmp90_ = FALSE;
	gboolean _tmp93_ = FALSE;
	gboolean _tmp96_ = FALSE;
	gboolean _tmp99_ = FALSE;
	gboolean _tmp102_ = FALSE;
	gboolean _tmp105_ = FALSE;
	gchar* new_text = NULL;
	const gchar* _tmp108_ = NULL;
	const gchar* _tmp109_ = NULL;
	gchar* _tmp110_ = NULL;
	GdTaggedEntry* _tmp111_ = NULL;
	gulong _tmp112_ = 0UL;
	gboolean _tmp113_ = FALSE;
	gboolean _tmp114_ = FALSE;
	gboolean _tmp115_ = FALSE;
	gboolean _tmp118_ = FALSE;
	gboolean _tmp120_ = FALSE;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data53_ = g_slice_new0 (Block53Data);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data53_->_ref_count_ = 1;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data53_->self = g_object_ref (self);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	handled = FALSE;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _tmp0_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp1_ != BOXES_UI_STATE_COLLECTION) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		result = handled;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		block53_data_unref (_data53_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_data53_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		return result;
#line 659 "searchbar.c"
	}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = self->priv->entry;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = gtk_widget_get_realized ((GtkWidget*) _tmp2_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (!_tmp3_) {
#line 667 "searchbar.c"
		ClutterActor* _tmp4_ = NULL;
		ClutterActor* _tmp5_ = NULL;
		ClutterActor* _tmp6_ = NULL;
		ClutterActor* _tmp7_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp4_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp5_ = _tmp4_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		clutter_actor_show (_tmp5_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp6_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp7_ = _tmp6_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		clutter_actor_hide (_tmp7_);
#line 684 "searchbar.c"
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data53_->preedit_changed = FALSE;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp8_ = self->priv->entry;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp9_ = g_signal_connect_data ((GtkEntry*) _tmp8_, "preedit-changed", (GCallback) ___lambda30__gtk_entry_preedit_changed, block53_data_ref (_data53_), (GClosureNotify) block53_data_unref, 0);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	preedit_changed_id = _tmp9_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp10_ = boxes_searchbar_get_text (self);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp11_ = _tmp10_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	old_text = _tmp12_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp13_ = boxes_searchbar_get_visible (self);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp14_ = _tmp13_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (!_tmp14_) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_text (self, "");
#line 710 "searchbar.c"
	}
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp16_ = boxes_searchbar_get_visible (self);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp17_ = _tmp16_;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp17_) {
#line 718 "searchbar.c"
		GdkEventKey _tmp18_ = {0};
		guint _tmp19_ = 0U;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp18_ = *event;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp19_ = _tmp18_.keyval;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp15_ = _tmp19_ == ((guint) GDK_KEY_Escape);
#line 727 "searchbar.c"
	} else {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp15_ = FALSE;
#line 731 "searchbar.c"
	}
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp20_ = _tmp15_;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp20_) {
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_text (self, "");
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_visible (self, FALSE);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		result = TRUE;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_g_free0 (old_text);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		block53_data_unref (_data53_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_data53_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		return result;
#line 751 "searchbar.c"
	}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp22_ = self->priv->entry;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_get ((GtkWidget*) _tmp22_, "has-focus", &_tmp23_, NULL);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp24_ = _tmp23_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (!_tmp24_) {
#line 761 "searchbar.c"
		gboolean _tmp25_ = FALSE;
		GdkEventKey _tmp26_ = {0};
		guint _tmp27_ = 0U;
		gboolean _tmp30_ = FALSE;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp26_ = *event;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp27_ = _tmp26_.keyval;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		if (_tmp27_ == ((guint) GDK_KEY_space)) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
			_tmp25_ = TRUE;
#line 774 "searchbar.c"
		} else {
			GdkEventKey _tmp28_ = {0};
			guint _tmp29_ = 0U;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
			_tmp28_ = *event;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
			_tmp29_ = _tmp28_.keyval;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
			_tmp25_ = _tmp29_ == ((guint) GDK_KEY_Return);
#line 784 "searchbar.c"
		}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp30_ = _tmp25_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp21_ = _tmp30_;
#line 790 "searchbar.c"
	} else {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp21_ = FALSE;
#line 794 "searchbar.c"
	}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp31_ = _tmp21_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp31_) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		result = FALSE;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_g_free0 (old_text);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		block53_data_unref (_data53_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_data53_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		return result;
#line 810 "searchbar.c"
	}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	res = FALSE;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp50_ = *event;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp51_ = _tmp50_.keyval;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp51_ != ((guint) GDK_KEY_Tab)) {
#line 820 "searchbar.c"
		GdkEventKey _tmp52_ = {0};
		guint _tmp53_ = 0U;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp52_ = *event;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp53_ = _tmp52_.keyval;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp49_ = _tmp53_ != ((guint) GDK_KEY_KP_Tab);
#line 829 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp49_ = FALSE;
#line 833 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp54_ = _tmp49_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp54_) {
#line 839 "searchbar.c"
		GdkEventKey _tmp55_ = {0};
		guint _tmp56_ = 0U;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp55_ = *event;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp56_ = _tmp55_.keyval;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp48_ = _tmp56_ != ((guint) GDK_KEY_Up);
#line 848 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp48_ = FALSE;
#line 852 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp57_ = _tmp48_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp57_) {
#line 858 "searchbar.c"
		GdkEventKey _tmp58_ = {0};
		guint _tmp59_ = 0U;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp58_ = *event;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp59_ = _tmp58_.keyval;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp47_ = _tmp59_ != ((guint) GDK_KEY_KP_Up);
#line 867 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp47_ = FALSE;
#line 871 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp60_ = _tmp47_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp60_) {
#line 877 "searchbar.c"
		GdkEventKey _tmp61_ = {0};
		guint _tmp62_ = 0U;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp61_ = *event;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp62_ = _tmp61_.keyval;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp46_ = _tmp62_ != ((guint) GDK_KEY_Down);
#line 886 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp46_ = FALSE;
#line 890 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp63_ = _tmp46_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp63_) {
#line 896 "searchbar.c"
		GdkEventKey _tmp64_ = {0};
		guint _tmp65_ = 0U;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp64_ = *event;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp65_ = _tmp64_.keyval;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp45_ = _tmp65_ != ((guint) GDK_KEY_KP_Down);
#line 905 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp45_ = FALSE;
#line 909 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp66_ = _tmp45_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp66_) {
#line 915 "searchbar.c"
		GdkEventKey _tmp67_ = {0};
		guint _tmp68_ = 0U;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp67_ = *event;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp68_ = _tmp67_.keyval;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp44_ = _tmp68_ != ((guint) GDK_KEY_Left);
#line 924 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp44_ = FALSE;
#line 928 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp69_ = _tmp44_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp69_) {
#line 934 "searchbar.c"
		GdkEventKey _tmp70_ = {0};
		guint _tmp71_ = 0U;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp70_ = *event;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp71_ = _tmp70_.keyval;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp43_ = _tmp71_ != ((guint) GDK_KEY_KP_Left);
#line 943 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp43_ = FALSE;
#line 947 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp72_ = _tmp43_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp72_) {
#line 953 "searchbar.c"
		GdkEventKey _tmp73_ = {0};
		guint _tmp74_ = 0U;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp73_ = *event;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp74_ = _tmp73_.keyval;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp42_ = _tmp74_ != ((guint) GDK_KEY_Right);
#line 962 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp42_ = FALSE;
#line 966 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp75_ = _tmp42_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp75_) {
#line 972 "searchbar.c"
		GdkEventKey _tmp76_ = {0};
		guint _tmp77_ = 0U;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp76_ = *event;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp77_ = _tmp76_.keyval;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp41_ = _tmp77_ != ((guint) GDK_KEY_KP_Right);
#line 981 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp41_ = FALSE;
#line 985 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp78_ = _tmp41_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp78_) {
#line 991 "searchbar.c"
		GdkEventKey _tmp79_ = {0};
		guint _tmp80_ = 0U;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp79_ = *event;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp80_ = _tmp79_.keyval;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp40_ = _tmp80_ != ((guint) GDK_KEY_Home);
#line 1000 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp40_ = FALSE;
#line 1004 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp81_ = _tmp40_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp81_) {
#line 1010 "searchbar.c"
		GdkEventKey _tmp82_ = {0};
		guint _tmp83_ = 0U;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp82_ = *event;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp83_ = _tmp82_.keyval;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp39_ = _tmp83_ != ((guint) GDK_KEY_KP_Home);
#line 1019 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp39_ = FALSE;
#line 1023 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp84_ = _tmp39_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp84_) {
#line 1029 "searchbar.c"
		GdkEventKey _tmp85_ = {0};
		guint _tmp86_ = 0U;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp85_ = *event;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp86_ = _tmp85_.keyval;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp38_ = _tmp86_ != ((guint) GDK_KEY_End);
#line 1038 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp38_ = FALSE;
#line 1042 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp87_ = _tmp38_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp87_) {
#line 1048 "searchbar.c"
		GdkEventKey _tmp88_ = {0};
		guint _tmp89_ = 0U;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp88_ = *event;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp89_ = _tmp88_.keyval;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp37_ = _tmp89_ != ((guint) GDK_KEY_KP_End);
#line 1057 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp37_ = FALSE;
#line 1061 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp90_ = _tmp37_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp90_) {
#line 1067 "searchbar.c"
		GdkEventKey _tmp91_ = {0};
		guint _tmp92_ = 0U;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp91_ = *event;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp92_ = _tmp91_.keyval;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp36_ = _tmp92_ != ((guint) GDK_KEY_Page_Up);
#line 1076 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp36_ = FALSE;
#line 1080 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp93_ = _tmp36_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp93_) {
#line 1086 "searchbar.c"
		GdkEventKey _tmp94_ = {0};
		guint _tmp95_ = 0U;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp94_ = *event;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp95_ = _tmp94_.keyval;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp35_ = _tmp95_ != ((guint) GDK_KEY_KP_Page_Up);
#line 1095 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp35_ = FALSE;
#line 1099 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp96_ = _tmp35_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp96_) {
#line 1105 "searchbar.c"
		GdkEventKey _tmp97_ = {0};
		guint _tmp98_ = 0U;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp97_ = *event;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp98_ = _tmp97_.keyval;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp34_ = _tmp98_ != ((guint) GDK_KEY_Page_Down);
#line 1114 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp34_ = FALSE;
#line 1118 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp99_ = _tmp34_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp99_) {
#line 1124 "searchbar.c"
		GdkEventKey _tmp100_ = {0};
		guint _tmp101_ = 0U;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp100_ = *event;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp101_ = _tmp100_.keyval;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp33_ = _tmp101_ != ((guint) GDK_KEY_KP_Page_Down);
#line 1133 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp33_ = FALSE;
#line 1137 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp102_ = _tmp33_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp102_) {
#line 1143 "searchbar.c"
		GdkEventKey _tmp103_ = {0};
		GdkModifierType _tmp104_ = 0;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp103_ = *event;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp104_ = _tmp103_.state;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp32_ = (_tmp104_ & (GDK_CONTROL_MASK | GDK_MOD1_MASK)) == 0;
#line 1152 "searchbar.c"
	} else {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp32_ = FALSE;
#line 1156 "searchbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp105_ = _tmp32_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp105_) {
#line 1162 "searchbar.c"
		GdTaggedEntry* _tmp106_ = NULL;
		gboolean _tmp107_ = FALSE;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp106_ = self->priv->entry;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp107_ = gtk_widget_event ((GtkWidget*) _tmp106_, (GdkEvent*) (event));
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		res = _tmp107_;
#line 1171 "searchbar.c"
	}
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp108_ = boxes_searchbar_get_text (self);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp109_ = _tmp108_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp110_ = g_strdup (_tmp109_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	new_text = _tmp110_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp111_ = self->priv->entry;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp112_ = preedit_changed_id;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_signal_handler_disconnect ((GObject*) _tmp111_, _tmp112_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp115_ = res;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp115_) {
#line 1191 "searchbar.c"
		const gchar* _tmp116_ = NULL;
		const gchar* _tmp117_ = NULL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp116_ = new_text;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp117_ = old_text;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp114_ = g_strcmp0 (_tmp116_, _tmp117_) != 0;
#line 1200 "searchbar.c"
	} else {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp114_ = FALSE;
#line 1204 "searchbar.c"
	}
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp118_ = _tmp114_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp118_) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp113_ = TRUE;
#line 1212 "searchbar.c"
	} else {
		gboolean _tmp119_ = FALSE;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp119_ = _data53_->preedit_changed;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp113_ = _tmp119_;
#line 1219 "searchbar.c"
	}
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp120_ = _tmp113_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp120_) {
#line 1225 "searchbar.c"
		gboolean _tmp121_ = FALSE;
		gboolean _tmp122_ = FALSE;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		handled = TRUE;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp121_ = boxes_searchbar_get_visible (self);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp122_ = _tmp121_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		if (!_tmp122_) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
			boxes_searchbar_set_visible (self, TRUE);
#line 1238 "searchbar.c"
		} else {
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
			boxes_searchbar_grab_focus (self);
#line 1242 "searchbar.c"
		}
	}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = handled;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_free0 (new_text);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_free0 (old_text);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	block53_data_unref (_data53_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_data53_ = NULL;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 1257 "searchbar.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 1264 "searchbar.c"
}


static void boxes_searchbar_setup_searchbar (BoxesSearchbar* self) {
	GtkToolbar* toolbar = NULL;
	GtkToolbar* _tmp0_ = NULL;
	GtkToolbar* widget = NULL;
	GtkToolbar* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkToolItem* item = NULL;
	GtkToolItem* _tmp3_ = NULL;
	GdMarginContainer* margin = NULL;
	GdMarginContainer* _tmp4_ = NULL;
	GtkBox* box = NULL;
	GtkBox* _tmp5_ = NULL;
	GdTaggedEntry* _tmp6_ = NULL;
	GdTaggedEntry* _tmp7_ = NULL;
	GdTaggedEntry* _tmp8_ = NULL;
	GdTaggedEntry* _tmp9_ = NULL;
	GtkClutterActor* _tmp10_ = NULL;
	GtkClutterActor* _tmp11_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = (GtkToolbar*) gtk_toolbar_new ();
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp0_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	toolbar = _tmp0_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = _g_object_ref0 (toolbar);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	widget = _tmp1_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) toolbar);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_style_context_add_class (_tmp2_, GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = gtk_tool_item_new ();
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp3_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	item = _tmp3_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_toolbar_insert (toolbar, item, 0);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_tool_item_set_expand (item, TRUE);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp4_ = gd_margin_container_new ();
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp4_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	margin = _tmp4_;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_container_add ((GtkContainer*) item, (GtkWidget*) margin);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_set (margin, "min-margin", 6, NULL);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_set (margin, "max-margin", 64, NULL);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp5_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp5_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	box = _tmp5_;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_container_add ((GtkContainer*) margin, (GtkWidget*) box);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp6_ = gd_tagged_entry_new ();
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp6_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (self->priv->entry);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->entry = _tmp6_;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp7_ = self->priv->entry;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_set ((GtkWidget*) _tmp7_, "width-request", 260, NULL);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp8_ = self->priv->entry;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp8_, TRUE);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp9_ = self->priv->entry;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_container_add ((GtkContainer*) box, (GtkWidget*) _tmp9_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_widget_show_all ((GtkWidget*) widget);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp10_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) widget);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_ref_sink (_tmp10_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->gtk_actor = _tmp10_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp11_ = self->priv->gtk_actor;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp11_, "searchbar");
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (box);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (margin);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (item);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (widget);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (toolbar);
#line 1376 "searchbar.c"
}


static void boxes_searchbar_real_ui_state_changed (BoxesUI* base) {
	BoxesSearchbar * self;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = (BoxesSearchbar*) base;
#line 1384 "searchbar.c"
}


static ClutterActor* boxes_searchbar_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesSearchbar* self;
	GtkClutterActor* _tmp0_ = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = (BoxesSearchbar*) base;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = (ClutterActor*) _tmp0_;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 1400 "searchbar.c"
}


void boxes_searchbar_set_enable_key_handler (BoxesSearchbar* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = value;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp0_) {
#line 1412 "searchbar.c"
		BoxesApp* _tmp1_ = NULL;
		GtkApplicationWindow* _tmp2_ = NULL;
		gulong _tmp3_ = 0UL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp1_ = boxes_app_app;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp2_ = _tmp1_->window;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp3_ = self->priv->key_handler_id;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_signal_handler_unblock (_tmp2_, _tmp3_);
#line 1424 "searchbar.c"
	} else {
		BoxesApp* _tmp4_ = NULL;
		GtkApplicationWindow* _tmp5_ = NULL;
		gulong _tmp6_ = 0UL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp4_ = boxes_app_app;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp5_ = _tmp4_->window;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		_tmp6_ = self->priv->key_handler_id;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_signal_handler_block (_tmp5_, _tmp6_);
#line 1437 "searchbar.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_notify ((GObject *) self, "enable-key-handler");
#line 1441 "searchbar.c"
}


gboolean boxes_searchbar_get_visible (BoxesSearchbar* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->_visible;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = _tmp0_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 1456 "searchbar.c"
}


void boxes_searchbar_set_visible (BoxesSearchbar* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	BoxesApp* _tmp2_ = NULL;
	BoxesRevealer* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->_visible;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = value;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp0_ == _tmp1_) {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		return;
#line 1478 "searchbar.c"
	}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = boxes_app_app;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp3_ = _tmp2_->searchbar_revealer;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp4_ = value;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_revealer_set_revealed (_tmp3_, _tmp4_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp5_ = value;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	if (_tmp5_) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_grab_focus (self);
#line 1494 "searchbar.c"
	} else {
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_text (self, "");
#line 1498 "searchbar.c"
	}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp6_ = value;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv->_visible = _tmp6_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_notify ((GObject *) self, "visible");
#line 1506 "searchbar.c"
}


const gchar* boxes_searchbar_get_text (BoxesSearchbar* self) {
	const gchar* result;
	GdTaggedEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->entry;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = gtk_entry_get_text ((GtkEntry*) _tmp0_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp2_ = _tmp1_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	result = _tmp2_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	return result;
#line 1527 "searchbar.c"
}


void boxes_searchbar_set_text (BoxesSearchbar* self, const gchar* value) {
	GdTaggedEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_return_if_fail (self != NULL);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp0_ = self->priv->entry;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_tmp1_ = value;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	gtk_entry_set_text ((GtkEntry*) _tmp0_, _tmp1_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_notify ((GObject *) self, "text");
#line 1544 "searchbar.c"
}


static void boxes_searchbar_class_init (BoxesSearchbarClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	boxes_searchbar_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSearchbarPrivate));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_searchbar_real_ui_state_changed;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_searchbar_real_get_actor;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_searchbar_get_property;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_searchbar_set_property;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_searchbar_finalize;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCHBAR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCHBAR_ENABLE_KEY_HANDLER, g_param_spec_boolean ("enable-key-handler", "enable-key-handler", "enable-key-handler", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCHBAR_VISIBLE, g_param_spec_boolean ("visible", "visible", "visible", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SEARCHBAR_TEXT, g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1571 "searchbar.c"
}


static void boxes_searchbar_instance_init (BoxesSearchbar * self) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self->priv = BOXES_SEARCHBAR_GET_PRIVATE (self);
#line 1578 "searchbar.c"
}


static void boxes_searchbar_finalize (GObject* obj) {
	BoxesSearchbar * self;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SEARCHBAR, BoxesSearchbar);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	_g_object_unref0 (self->priv->entry);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	G_OBJECT_CLASS (boxes_searchbar_parent_class)->finalize (obj);
#line 1592 "searchbar.c"
}


GType boxes_searchbar_get_type (void) {
	static volatile gsize boxes_searchbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_searchbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSearchbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_searchbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSearchbar), 0, (GInstanceInitFunc) boxes_searchbar_instance_init, NULL };
		GType boxes_searchbar_type_id;
		boxes_searchbar_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesSearchbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_searchbar_type_id__volatile, boxes_searchbar_type_id);
	}
	return boxes_searchbar_type_id__volatile;
}


static void _vala_boxes_searchbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSearchbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SEARCHBAR, BoxesSearchbar);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	switch (property_id) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_ACTOR:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_VISIBLE:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_value_set_boolean (value, boxes_searchbar_get_visible (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_TEXT:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		g_value_set_string (value, boxes_searchbar_get_text (self));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 1631 "searchbar.c"
		default:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 1637 "searchbar.c"
	}
}


static void _vala_boxes_searchbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSearchbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SEARCHBAR, BoxesSearchbar);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
	switch (property_id) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_ENABLE_KEY_HANDLER:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_enable_key_handler (self, g_value_get_boolean (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_VISIBLE:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_visible (self, g_value_get_boolean (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		case BOXES_SEARCHBAR_TEXT:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		boxes_searchbar_set_text (self, g_value_get_string (value));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 1665 "searchbar.c"
		default:
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/searchbar.vala"
		break;
#line 1671 "searchbar.c"
	}
}



